import React from "react";
import {
  Box,
  Typography,
  Select,
  MenuItem,
  Button,
  FormControl,
  InputLabel,
} from "@mui/material";
import Grid from '@mui/material/Grid2';

const ProductDetails = () => {
  return (
    <Box sx={{ position: "relative"}}>
      {/* Flex Container */}
      <Box sx={{ display: "flex", flexDirection: "column", gap: 2}}>
        {/* Section 1: Product Info */}
        <Box>
          <Typography variant="h5" sx={{fontWeight:"bold", mb:2}}>Product Name</Typography>
          <Typography variant="body2" color="text.secondary">
            Product Type
          </Typography>
          <Typography
            variant="body1"
            sx={{ fontWeight: "bold" }}
          >
            $99.99
          </Typography>
        </Box>

        {/* Section 2: Description */}
        <Box sx={{mb:5}}>
          <Typography variant="h6" color="text.secondary" sx={{fontWeight:"bold", mb:3}}>
            Description
          </Typography>
          <Typography variant="body1" color="text.secondary" sx={{fontWeight:"400", mb:3 }}>
            Materials : Plain Soft Crepe with embroidery.
          </Typography>
          <Typography variant="body1" color="text.secondary" sx={{fontWeight:"400" }}>
            Care Instruction : Handwash for better care - Machine wash cotton items in cold or warm water. Do not use hot water as it may shrink the fabric - Use normal wash cycle and gentle detergent - Avoid using any harsh chemicals like bleach - Tumble dry on low setting, then promptly remove the item from the dryer to avoid wrinkles - Iron to remove wrinkle. Adding a spray starch will revive the crispness of cotton fabrics. Note : - Sale items are not returnable, exchangeable & refundable - Change of mind not applicable - Wrong washing, storing or ironing method which may cause product damage will not be entertained - Due to lighting effects, monitor’s brightness, contrast setting, etc., they could be some slight differences in the colour tone of the pictures and the actual item. Delivery : Postage will take around 3-5 working days from purchasing date
          </Typography>
        </Box>

        {/* Section 3: Controls */}
        <Grid container spacing={2} sx={{mt:"auto"}}>
          {/* Size Select */}
          <Grid item size={12}>
            <FormControl fullWidth>
              <InputLabel>Size</InputLabel>
              <Select defaultValue="">
                <MenuItem value="small">Small</MenuItem>
                <MenuItem value="medium">Medium</MenuItem>
                <MenuItem value="large">Large</MenuItem>
              </Select>
            </FormControl>
          </Grid>

          {/* Color Select */}
          <Grid item size={12}>
            <FormControl fullWidth>
              <InputLabel>Color</InputLabel>
              <Select defaultValue="">
                <MenuItem value="red">Red</MenuItem>
                <MenuItem value="blue">Blue</MenuItem>
                <MenuItem value="green">Green</MenuItem>
              </Select>
            </FormControl>
          </Grid>

          {/* Material Select */}
          <Grid item size={12}>
            <FormControl fullWidth>
              <InputLabel>Material</InputLabel>
              <Select defaultValue="">
                <MenuItem value="cotton">Cotton</MenuItem>
                <MenuItem value="wool">Wool</MenuItem>
                <MenuItem value="silk">Silk</MenuItem>
              </Select>
            </FormControl>
          </Grid>

          {/* Buy Now Button */}
          <Grid item size={12}>
            <Button
              onClick={()=>{window.location.href ="/cart"}}
              variant="contained"
              color="common.black"
              fullWidth
              sx={{
                backgroundColor: (theme) => theme.palette.common.black,
                color: "white",
                textTransform: "none",
                mt: 2,
                "&:hover": {
                  backgroundColor: (theme) => theme.palette.grey[900],
                },
              }}
            >
              BUY NOW
            </Button>
          </Grid>
        </Grid>
      </Box>

    </Box>
  );
};

export default ProductDetails;
